@@ -47,9 +47,9 @@ class SummaClient(BaseGrpcClient):
     async def attach_index(
         self,
         index_name: str,
-        attach_file_engine_request: index_service_pb.AttachFileEngineRequest | Dict | None,
-        attach_remote_engine_request: index_service_pb.AttachRemoteEngineRequest | Dict | None,
-        attach_ipfs_engine_request: index_service_pb.AttachIpfsEngineRequest | Dict | None,
+        attach_file_engine_request: Optional[Union[index_service_pb.AttachFileEngineRequest, Dict]] = None,
+        attach_remote_engine_request: Optional[Union[index_service_pb.AttachRemoteEngineRequest, Dict]] = None,
+        attach_ipfs_engine_request: Optional[Union[index_service_pb.AttachIpfsEngineRequest, Dict]] = None,
         request_id: Optional[str] = None,
         session_id: Optional[str] = None,
     ) -> index_service_pb.AttachIndexResponse:
@@ -142,14 +142,14 @@ class SummaClient(BaseGrpcClient):
     async def create_index(
         self,
         index_name: str,
-        index_engine: str | index_service_pb.CreateIndexEngineRequest,
+        index_engine: str,
         schema: str,
-        compression: str | int | None = None,
-        blocksize: int | None = None,
-        sort_by_field: Tuple | None = None,
-        index_attributes: index_service_pb.IndexAttributes | Dict | None = None,
-        request_id: str | None = None,
-        session_id: str | None = None,
+        compression: Optional[Union[str, int]] = None,
+        blocksize: Optional[int] = None,
+        sort_by_field: Optional[Tuple] = None,
+        index_attributes: Optional[Dict] = None,
+        request_id: Optional[str] = None,
+        session_id: Optional[str] = None,
     ) -> index_service_pb.CreateIndexResponse:
         """
         Create index
